@@ -1,4 +1,4 @@
 from .pub_sub_server import PubSubEndpoint
 from .pub_sub_client import PubSubClient
 from .event_broadcaster import EventBroadcaster, EventBroadcasterException
-from .event_notifier import EventNotifier, SubscriberId , SubscriptionId, Topic, TopicList, Subscription
\ No newline at end of file
+from .event_notifier import EventNotifier, SubscriberId , SubscriptionId, Topic, TopicList, Subscription, ALL_TOPICS
\ No newline at end of file
