@@ -6,9 +6,10 @@ from .logger import get_logger
 
 class RpcEventServerMethods(RpcMethodsBase):
 
-    def __init__(self, event_notifier: EventNotifier):
+    def __init__(self, event_notifier: EventNotifier, rpc_channel_get_remote_id: bool=False):
         super().__init__()
         self.event_notifier = event_notifier
+        self._rpc_channel_get_remote_id = rpc_channel_get_remote_id
         self.logger = get_logger('PubSubServer')
 
     async def subscribe(self, topics: TopicList = []) -> bool:
@@ -26,8 +27,17 @@ class RpcEventServerMethods(RpcMethodsBase):
                                  "data":data, "channel_id": self.channel.id})
                 await self.channel.other.notify(subscription=sub, data=data)
 
-            # We'll use our channel id as our subscriber id
-            sub_id = self.channel.id
+            if self._rpc_channel_get_remote_id:
+                # We'll use the remote channel id as our subscriber id
+                channel_other_channel_id = await self.channel.get_other_channel_id()
+                if channel_other_channel_id is None:
+                    self.logger.warning("could not fetch remote channel id, using local channel id to subscribe")
+                    sub_id = self.channel.id
+                else:
+                    sub_id = channel_other_channel_id
+            else:
+                # We'll use our channel id as our subscriber id
+                sub_id = self.channel.id
             await self.event_notifier.subscribe(sub_id, topics, callback)
             return True
         except Exception as err:
@@ -43,10 +53,10 @@ class RpcEventServerMethods(RpcMethodsBase):
             data (Any, optional): data to pass with the event to the subscribers. Defaults to None.
             sync (bool, optional): Should the server finish publishing before returning to us
             notifier_id(str,optional): A unique identifier of the source of the event
-                use a different id from the channel.id or the subscription id to receive own publications        
+                use a different id from the channel.id or the subscription id to receive own publications
 
         Returns:
-            bool: was the publish successful                
+            bool: was the publish successful
         """
         try:
             # use the given id or use our channel id
